summaryrefslogtreecommitdiff
path: root/NxWidgets/UnitTests/nxwm/main.cxx
diff options
context:
space:
mode:
authorpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2012-05-12 16:59:57 +0000
committerpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2012-05-12 16:59:57 +0000
commita9990e4f81cbd4e9201e60e9123b3caeb5ecb35b (patch)
treee1b475a8402986605c60b204f160ffeda35e9c26 /NxWidgets/UnitTests/nxwm/main.cxx
parentfb8f25a3f43d6c5a10dfa5a99b9cec55feec97f6 (diff)
downloadnuttx-a9990e4f81cbd4e9201e60e9123b3caeb5ecb35b.tar.gz
nuttx-a9990e4f81cbd4e9201e60e9123b3caeb5ecb35b.tar.bz2
nuttx-a9990e4f81cbd4e9201e60e9123b3caeb5ecb35b.zip
NxWM: Correct the calculation of the physical dispaly size
git-svn-id: svn://svn.code.sf.net/p/nuttx/code/trunk@4726 42af7a65-404d-4744-a932-0658087f49c3
Diffstat (limited to 'NxWidgets/UnitTests/nxwm/main.cxx')
-rw-r--r--NxWidgets/UnitTests/nxwm/main.cxx8
1 files changed, 4 insertions, 4 deletions
diff --git a/NxWidgets/UnitTests/nxwm/main.cxx b/NxWidgets/UnitTests/nxwm/main.cxx
index c230b9f87..271fd22c2 100644
--- a/NxWidgets/UnitTests/nxwm/main.cxx
+++ b/NxWidgets/UnitTests/nxwm/main.cxx
@@ -368,15 +368,15 @@ static bool startWindowManager(void)
#ifdef CONFIG_NXWM_TOUCHSCREEN
static bool createTouchScreen(void)
{
- // Get the physical size of the device in pixels
+ // Get the physical size of the display in pixels
- struct nxgl_size_s windowSize;
- (void)g_nxwmtest.taskbar->getWindowSize(&windowSize);
+ struct nxgl_size_s displaySize;
+ (void)g_nxwmtest.taskbar->getDisplaySize(displaySize);
// Create the touchscreen device
printf(MAIN_STRING "Creating CTouchscreen\n");
- g_nxwmtest.touchscreen = new NxWM::CTouchscreen(g_nxwmtest.taskbar, &windowSize);
+ g_nxwmtest.touchscreen = new NxWM::CTouchscreen(g_nxwmtest.taskbar, &displaySize);
if (!g_nxwmtest.touchscreen)
{
printf(MAIN_STRING "ERROR: Failed to create CTouchscreen\n");